<?php

namespace Drupal\monarch_symlink\Controller;

use Drupal\Core\Url;
use Drupal\system\MenuInterface;
use Drupal\Core\Entity\EntityInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Defines a controller to render a symlink.
 */
class MenuRedirectController extends SymlinkControllerBase {

  /**
   * Provides the menu redirect add form for a menu.
   *
   * @param \Drupal\system\MenuInterface $menu
   *   An entity representing a custom menu.
   *
   * @return array
   *   Returns the symlink creation form.
   */
  public function addMenuRedirect(MenuInterface $menu) {
    $redirect = $this->entityTypeManager()
      ->getStorage('menu_redirect')
      ->create([
        'menu_name' => $menu->id(),
      ]);
    return $this->entityFormBuilder()->getForm($redirect, 'add');
  }

  /**
   * The _title_callback for the page that renders a symlink.
   *
   * @param \Drupal\Core\Entity\EntityInterface $menu_redirect
   *   The current menu redirect.
   *
   * @return string
   *   The page title.
   */
  public function title(EntityInterface $menu_redirect) {
    return $menu_redirect->getTitle();
  }

  /**
   * {@inheritdoc}
   */
  public function view(EntityInterface $menu_redirect, $view_mode = 'full', $langcode = NULL) {
    $uri = $menu_redirect->link->uri;
    return new RedirectResponse(Url::fromUri($uri)->toString());
  }

}
